# rpc_to_mongo_db.py

Script to read clients attributes from perun rpc and write them to mongoDB.

## Usage

Install script requirements.

```
pip install -r ./requirements.txt
```

Script argument is path to config file.

```
./rpc_to_mongo_db.py ~/Documents/spreq-satosa-sync/config_template.yml
```
